Package: pscl
Version: 1.5.9
Date: 2024-01-14
Title: Political Science Computational Laboratory
Authors@R: c(
  person("Simon", "Jackman",
         role = c("aut", "cre"),
         email = "simon.jackman@sydney.edu.au",
         comment = c(ORCID = "0000-0001-7421-4034")
         ),
  person("Alex", "Tahk", role = c("ctb"), comment = c(ORCID = "0000-0001-7895-9420")),
  person("Achim", "Zeileis", role = c("ctb"), comment = c(ORCID = "0000-0003-0918-3766")),
  person("Christina", "Maimone", role = c("ctb"), comment = c(ORCID = "0000-0002-0402-6297")),
  person("James", "Fearon", role = c("ctb")),
  person("Zoe", "Meers", role = c("ctb"), comment = c(ORCID = "0000-0001-8045-6531"))
  )
Imports: MASS, datasets, grDevices, graphics, stats, utils
Suggests: lattice, MCMCpack, car, lmtest, sandwich, zoo, coda, vcd,
        mvtnorm, mgcv
Description: Bayesian analysis of item-response theory (IRT) models,
  roll call analysis; computing highest density regions; 
  maximum likelihood estimation of zero-inflated and hurdle models for count data;
  goodness-of-fit measures for GLMs;
  data sets used in writing	and teaching; seats-votes curves.
LazyData: true
License: GPL-2
URL: https://github.com/atahk/pscl
RoxygenNote: 7.3.0
NeedsCompilation: yes
Packaged: 2024-01-16 06:19:34 UTC; jackman
Author: Simon Jackman [aut, cre] (<https://orcid.org/0000-0001-7421-4034>),
  Alex Tahk [ctb] (<https://orcid.org/0000-0001-7895-9420>),
  Achim Zeileis [ctb] (<https://orcid.org/0000-0003-0918-3766>),
  Christina Maimone [ctb] (<https://orcid.org/0000-0002-0402-6297>),
  James Fearon [ctb],
  Zoe Meers [ctb] (<https://orcid.org/0000-0001-8045-6531>)
Maintainer: Simon Jackman <simon.jackman@sydney.edu.au>
Repository: CRAN
Date/Publication: 2024-01-31 08:00:03 UTC
Built: R 4.3.3; aarch64-apple-darwin20; 2025-01-25 21:52:30 UTC; unix
Archs: pscl.so.dSYM
